'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

/**
 * Utility for extracting color and backgroundColor props from components
 *
 * @method colorStyle
 * @param {Object} colors Color palette
 * @returns {Function} getColorStyle
 * @param {Object} props Style props from component
 */

var colorStyle = function colorStyle(colors) {
  return function (props) {
    colors = colors || {};

    var _ref = props || {};

    var color = _ref.color;
    var backgroundColor = _ref.backgroundColor;

    var result = {};

    if (color && colors[color]) {
      result.color = colors[color];
    } else if (typeof color === 'string') {
      result.color = color;
    }

    if (backgroundColor && colors[backgroundColor]) {
      result.backgroundColor = colors[backgroundColor];
    } else if (typeof backgroundColor === 'string') {
      result.backgroundColor = backgroundColor;
    }

    return result;
  };
};

exports.default = colorStyle;